@@ -644,6 +644,79 @@ squirrel =
  \\\\\\\\\\\\\\\\\\\\\\\\\\/   /  / `` ``  
      /////////   \\  /  \\      
  ML     \\\\\\\\\\\\___/_/___/      
-"
+",
+#Art by Max Strandberg, https://www.asciiart.eu/animals/fish
+goldfish=
+  "\n ------ \n%s \n ------ \n  \\\
+   \\       /\`-._
+    \\     /_,.._\`:-         
+      ,.-'  ,   \`-:..-')   
+      : o ):';      _  {   
+       \`-._ \`'__,.-'\\\`-.)
+           \`\\\\  \\,.-'\`   Max
+",
+#Art by Shanaka Dias
+
+alligator=
+  "\n ------ \n%s \n ------ \n   \\\   \n    \\\  \n     \\\
+           .-._   _ _ _ _ _ _ _ _
+.-''-.__.-'00  '-' ' ' ' ' ' ' ' '-.
+'.___ '    .   .--_'-' '-' '-' _'-' '._
+V: V 'vv-'   '_   '.       .'  _..' '.'.
+  '=.____.=_.--'   :_.__.__:_   '.   : :
+           (((____.-'        '-.  /   : :
+snd                          (((-'\\ .' /
+                           _____..'  .'
+                          '-._____.-'
+",
+stegosaurus=
+  "\n ------ \n%s \n ------ \n \\\   \n  \\\  \n   \\\
+
+   .-~~^-.
+ .'  O    \\
+(_____,    \\
+ `----.     \\
+       \\     \\
+        \\     \\
+         \\     `.             _ _
+          \\       ~- _ _ - ~       ~ - .
+           \\                              ~-.
+            \\                                `.
+             \\    /               /       \    \\
+              `. |         }     |         }    \\
+                `|        /      |        /       \\
+                 |       /       |       /          \\
+                 |      /`- _ _ _|      /.- ~ ^-.     \\
+                 |     /         |     /          `.    \\
+                 |     |         |     |             -.   ` . _ _ _ _ _ _
+                 |_____|         |_____|                ~ . _ _ _ _ _ _ _ >
+",
+# https://asciiart.website/index.php?art=animals/other%20(water)
+whale=
+  "\n            ------ \n           %s \n            ------ \n               \\\   \n                \\\  \n                 \\\
+     .-'          
+'--./ /     _.---.
+'-,  (__..-`       \\
+   \\          .     |
+    `,.__.   ,__.--/
+     '._/_.'___.-`
+",
+#https://www.asciiart.eu/animals/wolves
+
+wolf=
+  "\n              ------ \n             %s \n              ------ \n                  \\\   \n                   \\\  \n                    \\\
+                    .
+                   / V\\
+                  / \`  /
+                 <<   |
+                 /    |
+               /      |
+             /        |
+           /    \\  \\ /
+          (      ) | |
+  ________|   _/_  | |
+<__________\\______)\\__)"
+
+
 )
 
